/*
**  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
**	All rights reserved.
**  Sendmail, Inc. Confidential
**
**  $Id: batv-filter.h,v 1.16 2009/04/20 23:18:53 msk Exp $
*/

#ifndef _BATV_FILTER_H_
#define _BATV_FILTER_H_

#ifndef lint
static char batv_filter_h_id[] = "@(#)$Id: batv-filter.h,v 1.16 2009/04/20 23:18:53 msk Exp $";
#endif /* !lint */

#define	BATV_PRODUCT	"Sendmail BATV Filter"
#define	BATV_VERSION	"0.4.0"

#define	BATV_REJECTESC	"5.7.1"
#define	BATV_REJECTSMTP	"550"

#define	JOBIDUNKNOWN	"unknown-jobid"
#define	LOCALHOST	"localhost"
#define	XHEADERNAME	"X-BATV"

#define CMDLINEOPTS	"a:Abd:D:fhi:k:lnp:P:sSu:Vx"

#define	BUFRSZ		512
#define	MAXARGV		2048
#define	MAXHEADER	128
#define	SHA1_DIGEST_SIZE 20
#define	SIGLIFETIME	7

/* make sure we have TRUE and FALSE */
#ifndef FALSE
# define FALSE		0
#endif /* ! FALSE */
#ifndef TRUE
# define TRUE		1
#endif /* ! TRUE */

/* ...and other things */
#ifndef MAXHOSTNAMELEN
# define MAXHOSTNAMELEN	256
#endif /* ! MAXHOSTNAMELEN */
#ifndef _PATH_DEVNULL
# define _PATH_DEVNULL	"/dev/null"
#endif /* ! _PATH_DEVNULL */

#endif /* ! _BATV_FILTER_H_ */
